summaryrefslogtreecommitdiffstats
path: root/ppapi/native_client/src
diff options
context:
space:
mode:
Diffstat (limited to 'ppapi/native_client/src')
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/browser_globals.cc8
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/browser_globals.h4
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.cc6
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.h4
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb.cc2
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.cc6
-rw-r--r--ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.h6
7 files changed, 19 insertions, 17 deletions
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.cc b/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.cc
index 001158e..284e56d 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.cc
+++ b/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.cc
@@ -318,10 +318,10 @@ const PPB_Var* PPBVarInterface() {
return ppb;
}
-const PPB_VarArrayBuffer_Dev* PPBVarArrayBufferInterface() {
- static const PPB_VarArrayBuffer_Dev* ppb =
- static_cast<const PPB_VarArrayBuffer_Dev*>(
- GetBrowserInterfaceSafe(PPB_VAR_ARRAY_BUFFER_DEV_INTERFACE));
+const PPB_VarArrayBuffer* PPBVarArrayBufferInterface() {
+ static const PPB_VarArrayBuffer* ppb =
+ static_cast<const PPB_VarArrayBuffer*>(
+ GetBrowserInterfaceSafe(PPB_VAR_ARRAY_BUFFER_INTERFACE));
return ppb;
}
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.h b/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.h
index 8d63f38..913cf10 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.h
+++ b/ppapi/native_client/src/shared/ppapi_proxy/browser_globals.h
@@ -12,7 +12,6 @@
#include "ppapi/c/dev/ppb_memory_dev.h"
#include "ppapi/c/dev/ppb_scrollbar_dev.h"
#include "ppapi/c/dev/ppb_testing_dev.h"
-#include "ppapi/c/dev/ppb_var_array_buffer_dev.h"
#include "ppapi/c/dev/ppb_websocket_dev.h"
#include "ppapi/c/dev/ppb_widget_dev.h"
#include "ppapi/c/dev/ppb_zoom_dev.h"
@@ -35,6 +34,7 @@
#include "ppapi/c/ppb_url_request_info.h"
#include "ppapi/c/ppb_url_response_info.h"
#include "ppapi/c/ppb_var.h"
+#include "ppapi/c/ppb_var_array_buffer.h"
#include "ppapi/c/ppb_view.h"
#include "ppapi/c/private/ppb_net_address_private.h"
#include "ppapi/c/private/ppb_pdf.h"
@@ -130,7 +130,7 @@ const PPB_URLLoader* PPBURLLoaderInterface();
const PPB_URLRequestInfo* PPBURLRequestInfoInterface();
const PPB_URLResponseInfo* PPBURLResponseInfoInterface();
const PPB_Var* PPBVarInterface(); // shared
-const PPB_VarArrayBuffer_Dev* PPBVarArrayBufferInterface(); // shared
+const PPB_VarArrayBuffer* PPBVarArrayBufferInterface(); // shared
const PPB_View* PPBViewInterface();
const PPB_WheelInputEvent* PPBWheelInputEventInterface();
const PPB_WebSocket_Dev* PPBWebSocketInterface();
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.cc b/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.cc
index 1aef642..493cacb 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.cc
+++ b/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.cc
@@ -85,9 +85,9 @@ const PPB_Var* PPBVarInterface() {
GetBrowserInterfaceSafe(PPB_VAR_INTERFACE));
}
-const PPB_VarArrayBuffer_Dev* PPBVarArrayBufferInterface() {
- return static_cast<const PPB_VarArrayBuffer_Dev*>(
- GetBrowserInterfaceSafe(PPB_VAR_ARRAY_BUFFER_DEV_INTERFACE));
+const PPB_VarArrayBuffer* PPBVarArrayBufferInterface() {
+ return static_cast<const PPB_VarArrayBuffer*>(
+ GetBrowserInterfaceSafe(PPB_VAR_ARRAY_BUFFER_INTERFACE));
}
const PPB_WebSocket_Dev* PPBWebSocketInterface() {
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.h b/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.h
index 18ea331..fbcba2d 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.h
+++ b/ppapi/native_client/src/shared/ppapi_proxy/plugin_globals.h
@@ -6,7 +6,6 @@
#define NATIVE_CLIENT_SRC_SHARED_PPAPI_PROXY_PLUGIN_GLOBALS_H_
#include "ppapi/c/dev/ppb_memory_dev.h"
-#include "ppapi/c/dev/ppb_var_array_buffer_dev.h"
#include "ppapi/c/dev/ppb_websocket_dev.h"
#include "ppapi/c/dev/ppp_find_dev.h"
#include "ppapi/c/dev/ppp_printing_dev.h"
@@ -18,6 +17,7 @@
#include "ppapi/c/ppb.h"
#include "ppapi/c/ppb_core.h"
#include "ppapi/c/ppb_var.h"
+#include "ppapi/c/ppb_var_array_buffer.h"
#include "ppapi/c/ppp_input_event.h"
#include "ppapi/c/ppp_instance.h"
#include "ppapi/c/ppp_messaging.h"
@@ -55,7 +55,7 @@ const void* GetBrowserInterfaceSafe(const char* interface_name);
const PPB_Core* PPBCoreInterface(); // shared
const PPB_Memory_Dev* PPBMemoryInterface(); // shared
const PPB_Var* PPBVarInterface(); // shared
-const PPB_VarArrayBuffer_Dev* PPBVarArrayBufferInterface(); // shared
+const PPB_VarArrayBuffer* PPBVarArrayBufferInterface(); // shared
const PPB_WebSocket_Dev* PPBWebSocketInterface();
// Support for getting PPP_ plugin interfaces.
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb.cc b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb.cc
index b57a8d4..1efbab9 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb.cc
+++ b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb.cc
@@ -98,7 +98,7 @@ InterfaceMapElement interface_map[] = {
{ PPB_URLREQUESTINFO_INTERFACE, PluginURLRequestInfo::GetInterface(), true },
{ PPB_URLRESPONSEINFO_INTERFACE, PluginURLResponseInfo::GetInterface(),
true },
- { PPB_VAR_ARRAY_BUFFER_DEV_INTERFACE, PluginVar::GetArrayBufferInterface(),
+ { PPB_VAR_ARRAY_BUFFER_INTERFACE, PluginVar::GetArrayBufferInterface(),
true },
{ PPB_VAR_INTERFACE, PluginVar::GetInterface(), true },
{ PPB_VAR_INTERFACE_1_0, PluginVar::GetInterface1_0(), true },
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.cc b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.cc
index b642eb0..d9700da 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.cc
+++ b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.cc
@@ -118,6 +118,8 @@ void* Map(PP_Var var) {
PluginVar::DebugString(var).c_str());
SharedArrayBufferProxyVar buffer_var = ArrayBufferProxyVar::CastFromProxyVar(
ProxyVarCache::GetInstance().SharedProxyVarForVar(var));
+ if (!buffer_var)
+ return NULL;
void* data = buffer_var->buffer();
DebugPrintf("PPB_VarArrayBuffer::Map: buffer=%p\n", data);
return data;
@@ -151,8 +153,8 @@ const PPB_Var_1_0* PluginVar::GetInterface1_0() {
return &var_interface;
}
-const PPB_VarArrayBuffer_Dev* PluginVar::GetArrayBufferInterface() {
- static const PPB_VarArrayBuffer_Dev interface = {
+const PPB_VarArrayBuffer* PluginVar::GetArrayBufferInterface() {
+ static const PPB_VarArrayBuffer interface = {
CreateArrayBuffer,
ByteLength,
Map,
diff --git a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.h b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.h
index d6cb40e..21f8169 100644
--- a/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.h
+++ b/ppapi/native_client/src/shared/ppapi_proxy/plugin_ppb_var.h
@@ -9,9 +9,9 @@
#include "native_client/src/include/nacl_macros.h"
#include "native_client/src/include/portability.h"
-#include "ppapi/c/dev/ppb_var_array_buffer_dev.h"
#include "ppapi/c/pp_var.h"
#include "ppapi/c/ppb_var.h"
+#include "ppapi/c/ppb_var_array_buffer.h"
namespace ppapi_proxy {
@@ -25,8 +25,8 @@ class PluginVar {
// Returns the 1.0 interface to support backwards-compatibility.
static const PPB_Var_1_0* GetInterface1_0();
- // Returns an interface pointer for the PPB_VarArrayBuffer_Dev interface.
- static const PPB_VarArrayBuffer_Dev* GetArrayBufferInterface();
+ // Returns an interface pointer for the PPB_VarArrayBuffer interface.
+ static const PPB_VarArrayBuffer* GetArrayBufferInterface();
// String helpers.
static PP_Var StringToPPVar(const std::string& str);